<?php

namespace Litecms\CouponSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\CouponSetting\Models\Couponsetting;

class CouponsettingPolicy
{

    /**
     * Determine if the given user can view the couponsetting.
     *
     * @param UserPolicy $user
     * @param Couponsetting $couponsetting
     *
     * @return bool
     */
    public function view(UserPolicy $user, Couponsetting $couponsetting)
    {
        if ($user->canDo('coupon__setting.couponsetting.view') && $user->isAdmin()) {
            return true;
        }

        return $couponsetting->user_id == user_id() && $couponsetting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a couponsetting.
     *
     * @param UserPolicy $user
     * @param Couponsetting $couponsetting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('coupon__setting.couponsetting.create');
    }

    /**
     * Determine if the given user can update the given couponsetting.
     *
     * @param UserPolicy $user
     * @param Couponsetting $couponsetting
     *
     * @return bool
     */
    public function update(UserPolicy $user, Couponsetting $couponsetting)
    {
        if ($user->canDo('coupon__setting.couponsetting.edit') && $user->isAdmin()) {
            return true;
        }

        return $couponsetting->user_id == user_id() && $couponsetting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given couponsetting.
     *
     * @param UserPolicy $user
     * @param Couponsetting $couponsetting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Couponsetting $couponsetting)
    {
        return $couponsetting->user_id == user_id() && $couponsetting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given couponsetting.
     *
     * @param UserPolicy $user
     * @param Couponsetting $couponsetting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Couponsetting $couponsetting)
    {
        if ($user->canDo('coupon__setting.couponsetting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given couponsetting.
     *
     * @param UserPolicy $user
     * @param Couponsetting $couponsetting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Couponsetting $couponsetting)
    {
        if ($user->canDo('coupon__setting.couponsetting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
